pub trait Textify {
// Required methods
fn textify<S: Scope, W: Write>(&self, ctx: &S, w: &mut W) -> Result;
fn name() -> &'static str;
}Expand description
A trait for types that can be output in text format.
This trait is used to convert a Substrait type into a string representation that can be written to a text writer.
Required Methods
fn textify<S: Scope, W: Write>(&self, ctx: &S, w: &mut W) -> Result
fn name() -> &'static str
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl Textify for Nullability
impl Textify for Nullability
Sourceimpl Textify for FieldReference
impl Textify for FieldReference
Sourceimpl Textify for ScalarFunction
impl Textify for ScalarFunction
Sourceimpl Textify for AdvancedExtension
impl Textify for AdvancedExtension
Sourcefn textify<S: Scope, W: Write>(&self, ctx: &S, w: &mut W) -> Result
fn textify<S: Scope, W: Write>(&self, ctx: &S, w: &mut W) -> Result
Textify all enhancement and optimization lines for an AdvancedExtension.
Writes one + Enh: line (if an enhancement is present) followed by zero
or more + Opt: lines, each preceded by a newline.